@@ -8,10 +8,12 @@ with open('./.Clever.unp/Guide.undl') as code:
 inter = Interpreter.Interpret(lines)
 inter.dictionary()
 form = Interpreter.Form(inter.Form, inter.FormDict)
-app = APP.Main()
-app.file_tree('./.Clever.unp')
-app.main_loop()
-
-
+inter.dictionary()
+app = APP.App()
+app.init_ui()
+if __name__ == '__main__':
+    app = QApplication(sys.argv)
+    ex = App()
+    sys.exit(app.exec_())
 # db = DB.LocalDB("./.Clever.unp")
 # db.create()
